package
Version:
v1.0.11
Opens a new window with list of versions in this module.
Published: Apr 28, 2026
License: MIT
Opens a new window with license information.
Imports: 34
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Execute runs the root command.
RootCmd returns the root cobra command. Useful for docs/manpage generation.
func SetVersion(v, c, d string)
SetVersion sets build-time version information.
App holds the dependencies needed for CLI execution.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.